slepc-3.18.0 2022-10-01
Report Typos and Errors

# DSCreate

Creates a DS context.

### Synopsis

    #include "slepcds.h"
    PetscErrorCode DSCreate(MPI_Comm comm,DS *newds)

Collective

### Input Parameter

| comm | - MPI communicator

### Output Parameter

| newds | - location to put the DS context

### Note

DS objects are not intended for normal users but only for advanced user that for instance implement their own solvers.

### See Also

DSDestroy(), DS

### Level

beginner

### Location

src/sys/classes/ds/interface/dsbasic.c
Index of all DS routines
Table of Contents for all manual pages
Index of all manual pages